# JSON-RPC 接口规范文档

## 📌 目录
- [协议基础信息](#协议基础信息)
- [请求格式规范](#请求格式规范)
- [响应格式规范](#响应格式规范)

## 协议基础信息

> 🌐 **JSON-RPC 通信规范**

| 项目            | 值                   | 说明                     |
|-----------------|---------------------|--------------------------|
| 🔖 协议版本      | JSON-RPC 2.0        | 遵循最新2.0协议规范       |
| 📤 传输协议      | HTTP POST           | 仅支持POST方法            |
| 🚪 服务端点      | `127.0.0.1:8848`    | 生产环境请替换为实际地址   |
| 🕒 超时时间      | 5000ms              | 建议客户端设置超时        |
| 📝 Content-Type | `application/json`  | 必须严格设置此请求头       |

---

## 请求格式规范

### 📦 请求示例
```json
{
  "jsonrpc": "2.0",
  "method": "ServiceName.method",
  "params": {
    "company_info": {
      "id": 5,
      "name": "德木智造",
      "full_name": "苏州德木智造科技有限公司",
      "domain": "drp",
      "owner": "ykxiao",
      "mobile": "13712279001",
      "address": "江苏省苏州市太仓市太仓港港口开发区北环路20号809室",
      "org_code": "91320585MAE1L3233J",
      "email": "yk_9001@icloud.com"
    },
    "userInfo": {
      "id": 8,
      "company_id": 5,
      "user_type": 2,
      "login_name": "ykk"
    }
  },
  "id": "req_123456"
}
```

## 响应格式规范

### ✅ 成功响应
```json
{
  "jsonrpc": "2.0",
  "result": {
    "status": "success",
    "data": {
      "request_id": "req_123456",
      "processed_at": "2023-08-20 15:30:45"
    }
  },
  "id": "req_123456"
}
```

### ❌ 错误响应
```json
{
  "jsonrpc": "2.0",
  "error": {
    "code": -32000,
    "message": "企业信息验证失败",
    "data": {
      "field": "org_code",
      "reason": "统一信用代码格式不正确"
    }
  },
  "id": "req_123456"
}
```

### 🚨 错误码说明

| 错误码   | HTTP状态码 | 说明                  | 解决方案                |
|---------|------------|-----------------------|-------------------------|
| -32700  | 400        | 解析错误              | 检查JSON格式            |
| -32600  | 400        | 无效请求              | 验证请求参数            |
| -32601  | 404        | 方法不存在            | 检查method名称          |
| -32602  | 400        | 无效参数              | 检查params参数          |
| -32603  | 500        | 内部错误              | 联系技术支持            |
| -32000  | 200        | 业务逻辑错误          | 查看error.data详情      |
| -32001  | 401        | 未授权访问            | 检查认证信息            |